@@ -1,17 +1,17 @@
 #!/bin/bash
 
 echo "::group::Build nuclei"
-rm integration-test nuclei 2>/dev/null
-cd ../v2/cmd/nuclei
+rm integration-test fuzzplayground nuclei 2>/dev/null
+cd ../cmd/nuclei
 go build -race .
-mv nuclei ../../../integration_tests/nuclei 
+mv nuclei ../../integration_tests/nuclei 
 echo "::endgroup::"
 
 echo "::group::Build nuclei integration-test"
 cd ../integration-test
 go build
-mv integration-test ../../../integration_tests/integration-test 
-cd ../../../integration_tests
+mv integration-test ../../integration_tests/integration-test 
+cd ../../integration_tests
 echo "::endgroup::"
 
 echo "::group::Installing nuclei templates"
